// This file is safe to edit. Once it exists it will not be overwritten

package restapi

import (
	"crypto/tls"
	"net/http"

	"github.com/go-openapi/errors"
	"github.com/go-openapi/runtime"
	"github.com/go-openapi/runtime/middleware"

	"code.fbi.h-da.de/cocsn/cocsn-api/api/restapi/operations"
	"code.fbi.h-da.de/cocsn/cocsn-api/api/restapi/operations/data"
	"code.fbi.h-da.de/cocsn/cocsn-api/api/restapi/operations/operationsops"
	"code.fbi.h-da.de/cocsn/cocsn-api/api/restapi/operations/root"
	"code.fbi.h-da.de/cocsn/cocsn-api/api/restapi/operations/yang_library_version"
)

//go:generate swagger generate server --target ../../api --name Cocsn --spec ../../cocsn.json --principal interface{}

func configureFlags(api *operations.CocsnAPI) {
	// api.CommandLineOptionsGroups = []swag.CommandLineOptionsGroup{ ... }
}

func configureAPI(api *operations.CocsnAPI) http.Handler {
	// configure the api here
	api.ServeError = errors.ServeError

	// Set your custom logger if needed. Default one is log.Printf
	// Expected interface func(string, ...interface{})
	//
	// Example:
	// api.Logger = log.Printf

	api.UseSwaggerUI()
	// To continue using redoc as your UI, uncomment the following line
	// api.UseRedoc()

	api.JSONConsumer = runtime.JSONConsumer()

	api.JSONProducer = runtime.JSONProducer()

	// Applies when the Authorization header is set with the Basic scheme
	if api.BasicAuthAuth == nil {
		api.BasicAuthAuth = func(user string, pass string) (interface{}, error) {
			return nil, errors.NotImplemented("basic auth  (basicAuth) has not yet been implemented")
		}
	}

	// Set your custom authorizer if needed. Default one is security.Authorized()
	// Expected interface runtime.Authorizer
	//
	// Example:
	// api.APIAuthorizer = security.Authorized()
	if api.DataDataCocsnInterfacesDeleteHandler == nil {
		api.DataDataCocsnInterfacesDeleteHandler = data.DataCocsnInterfacesDeleteHandlerFunc(func(params data.DataCocsnInterfacesDeleteParams, principal interface{}) middleware.Responder {
			return middleware.NotImplemented("operation data.DataCocsnInterfacesDelete has not yet been implemented")
		})
	}
	if api.DataDataCocsnInterfacesGetHandler == nil {
		api.DataDataCocsnInterfacesGetHandler = data.DataCocsnInterfacesGetHandlerFunc(func(params data.DataCocsnInterfacesGetParams, principal interface{}) middleware.Responder {
			return middleware.NotImplemented("operation data.DataCocsnInterfacesGet has not yet been implemented")
		})
	}
	if api.DataDataCocsnInterfacesInterfaceInterfaceNameAddressesAddressesIDDeleteHandler == nil {
		api.DataDataCocsnInterfacesInterfaceInterfaceNameAddressesAddressesIDDeleteHandler = data.DataCocsnInterfacesInterfaceInterfaceNameAddressesAddressesIDDeleteHandlerFunc(func(params data.DataCocsnInterfacesInterfaceInterfaceNameAddressesAddressesIDDeleteParams, principal interface{}) middleware.Responder {
			return middleware.NotImplemented("operation data.DataCocsnInterfacesInterfaceInterfaceNameAddressesAddressesIDDelete has not yet been implemented")
		})
	}
	if api.DataDataCocsnInterfacesInterfaceInterfaceNameAddressesAddressesIDGetHandler == nil {
		api.DataDataCocsnInterfacesInterfaceInterfaceNameAddressesAddressesIDGetHandler = data.DataCocsnInterfacesInterfaceInterfaceNameAddressesAddressesIDGetHandlerFunc(func(params data.DataCocsnInterfacesInterfaceInterfaceNameAddressesAddressesIDGetParams, principal interface{}) middleware.Responder {
			return middleware.NotImplemented("operation data.DataCocsnInterfacesInterfaceInterfaceNameAddressesAddressesIDGet has not yet been implemented")
		})
	}
	if api.DataDataCocsnInterfacesInterfaceInterfaceNameAddressesAddressesIDPatchHandler == nil {
		api.DataDataCocsnInterfacesInterfaceInterfaceNameAddressesAddressesIDPatchHandler = data.DataCocsnInterfacesInterfaceInterfaceNameAddressesAddressesIDPatchHandlerFunc(func(params data.DataCocsnInterfacesInterfaceInterfaceNameAddressesAddressesIDPatchParams, principal interface{}) middleware.Responder {
			return middleware.NotImplemented("operation data.DataCocsnInterfacesInterfaceInterfaceNameAddressesAddressesIDPatch has not yet been implemented")
		})
	}
	if api.DataDataCocsnInterfacesInterfaceInterfaceNameAddressesAddressesIDPutHandler == nil {
		api.DataDataCocsnInterfacesInterfaceInterfaceNameAddressesAddressesIDPutHandler = data.DataCocsnInterfacesInterfaceInterfaceNameAddressesAddressesIDPutHandlerFunc(func(params data.DataCocsnInterfacesInterfaceInterfaceNameAddressesAddressesIDPutParams, principal interface{}) middleware.Responder {
			return middleware.NotImplemented("operation data.DataCocsnInterfacesInterfaceInterfaceNameAddressesAddressesIDPut has not yet been implemented")
		})
	}
	if api.DataDataCocsnInterfacesInterfaceInterfaceNameDeleteHandler == nil {
		api.DataDataCocsnInterfacesInterfaceInterfaceNameDeleteHandler = data.DataCocsnInterfacesInterfaceInterfaceNameDeleteHandlerFunc(func(params data.DataCocsnInterfacesInterfaceInterfaceNameDeleteParams, principal interface{}) middleware.Responder {
			return middleware.NotImplemented("operation data.DataCocsnInterfacesInterfaceInterfaceNameDelete has not yet been implemented")
		})
	}
	if api.DataDataCocsnInterfacesInterfaceInterfaceNameEnabledDeleteHandler == nil {
		api.DataDataCocsnInterfacesInterfaceInterfaceNameEnabledDeleteHandler = data.DataCocsnInterfacesInterfaceInterfaceNameEnabledDeleteHandlerFunc(func(params data.DataCocsnInterfacesInterfaceInterfaceNameEnabledDeleteParams, principal interface{}) middleware.Responder {
			return middleware.NotImplemented("operation data.DataCocsnInterfacesInterfaceInterfaceNameEnabledDelete has not yet been implemented")
		})
	}
	if api.DataDataCocsnInterfacesInterfaceInterfaceNameEnabledGetHandler == nil {
		api.DataDataCocsnInterfacesInterfaceInterfaceNameEnabledGetHandler = data.DataCocsnInterfacesInterfaceInterfaceNameEnabledGetHandlerFunc(func(params data.DataCocsnInterfacesInterfaceInterfaceNameEnabledGetParams, principal interface{}) middleware.Responder {
			return middleware.NotImplemented("operation data.DataCocsnInterfacesInterfaceInterfaceNameEnabledGet has not yet been implemented")
		})
	}
	if api.DataDataCocsnInterfacesInterfaceInterfaceNameEnabledPatchHandler == nil {
		api.DataDataCocsnInterfacesInterfaceInterfaceNameEnabledPatchHandler = data.DataCocsnInterfacesInterfaceInterfaceNameEnabledPatchHandlerFunc(func(params data.DataCocsnInterfacesInterfaceInterfaceNameEnabledPatchParams, principal interface{}) middleware.Responder {
			return middleware.NotImplemented("operation data.DataCocsnInterfacesInterfaceInterfaceNameEnabledPatch has not yet been implemented")
		})
	}
	if api.DataDataCocsnInterfacesInterfaceInterfaceNameEnabledPutHandler == nil {
		api.DataDataCocsnInterfacesInterfaceInterfaceNameEnabledPutHandler = data.DataCocsnInterfacesInterfaceInterfaceNameEnabledPutHandlerFunc(func(params data.DataCocsnInterfacesInterfaceInterfaceNameEnabledPutParams, principal interface{}) middleware.Responder {
			return middleware.NotImplemented("operation data.DataCocsnInterfacesInterfaceInterfaceNameEnabledPut has not yet been implemented")
		})
	}
	if api.DataDataCocsnInterfacesInterfaceInterfaceNameGetHandler == nil {
		api.DataDataCocsnInterfacesInterfaceInterfaceNameGetHandler = data.DataCocsnInterfacesInterfaceInterfaceNameGetHandlerFunc(func(params data.DataCocsnInterfacesInterfaceInterfaceNameGetParams, principal interface{}) middleware.Responder {
			return middleware.NotImplemented("operation data.DataCocsnInterfacesInterfaceInterfaceNameGet has not yet been implemented")
		})
	}
	if api.DataDataCocsnInterfacesInterfaceInterfaceNameNameDeleteHandler == nil {
		api.DataDataCocsnInterfacesInterfaceInterfaceNameNameDeleteHandler = data.DataCocsnInterfacesInterfaceInterfaceNameNameDeleteHandlerFunc(func(params data.DataCocsnInterfacesInterfaceInterfaceNameNameDeleteParams, principal interface{}) middleware.Responder {
			return middleware.NotImplemented("operation data.DataCocsnInterfacesInterfaceInterfaceNameNameDelete has not yet been implemented")
		})
	}
	if api.DataDataCocsnInterfacesInterfaceInterfaceNameNameGetHandler == nil {
		api.DataDataCocsnInterfacesInterfaceInterfaceNameNameGetHandler = data.DataCocsnInterfacesInterfaceInterfaceNameNameGetHandlerFunc(func(params data.DataCocsnInterfacesInterfaceInterfaceNameNameGetParams, principal interface{}) middleware.Responder {
			return middleware.NotImplemented("operation data.DataCocsnInterfacesInterfaceInterfaceNameNameGet has not yet been implemented")
		})
	}
	if api.DataDataCocsnInterfacesInterfaceInterfaceNameNamePatchHandler == nil {
		api.DataDataCocsnInterfacesInterfaceInterfaceNameNamePatchHandler = data.DataCocsnInterfacesInterfaceInterfaceNameNamePatchHandlerFunc(func(params data.DataCocsnInterfacesInterfaceInterfaceNameNamePatchParams, principal interface{}) middleware.Responder {
			return middleware.NotImplemented("operation data.DataCocsnInterfacesInterfaceInterfaceNameNamePatch has not yet been implemented")
		})
	}
	if api.DataDataCocsnInterfacesInterfaceInterfaceNameNamePutHandler == nil {
		api.DataDataCocsnInterfacesInterfaceInterfaceNameNamePutHandler = data.DataCocsnInterfacesInterfaceInterfaceNameNamePutHandlerFunc(func(params data.DataCocsnInterfacesInterfaceInterfaceNameNamePutParams, principal interface{}) middleware.Responder {
			return middleware.NotImplemented("operation data.DataCocsnInterfacesInterfaceInterfaceNameNamePut has not yet been implemented")
		})
	}
	if api.DataDataCocsnInterfacesInterfaceInterfaceNameOperStatusDeleteHandler == nil {
		api.DataDataCocsnInterfacesInterfaceInterfaceNameOperStatusDeleteHandler = data.DataCocsnInterfacesInterfaceInterfaceNameOperStatusDeleteHandlerFunc(func(params data.DataCocsnInterfacesInterfaceInterfaceNameOperStatusDeleteParams, principal interface{}) middleware.Responder {
			return middleware.NotImplemented("operation data.DataCocsnInterfacesInterfaceInterfaceNameOperStatusDelete has not yet been implemented")
		})
	}
	if api.DataDataCocsnInterfacesInterfaceInterfaceNameOperStatusGetHandler == nil {
		api.DataDataCocsnInterfacesInterfaceInterfaceNameOperStatusGetHandler = data.DataCocsnInterfacesInterfaceInterfaceNameOperStatusGetHandlerFunc(func(params data.DataCocsnInterfacesInterfaceInterfaceNameOperStatusGetParams, principal interface{}) middleware.Responder {
			return middleware.NotImplemented("operation data.DataCocsnInterfacesInterfaceInterfaceNameOperStatusGet has not yet been implemented")
		})
	}
	if api.DataDataCocsnInterfacesInterfaceInterfaceNameOperStatusPatchHandler == nil {
		api.DataDataCocsnInterfacesInterfaceInterfaceNameOperStatusPatchHandler = data.DataCocsnInterfacesInterfaceInterfaceNameOperStatusPatchHandlerFunc(func(params data.DataCocsnInterfacesInterfaceInterfaceNameOperStatusPatchParams, principal interface{}) middleware.Responder {
			return middleware.NotImplemented("operation data.DataCocsnInterfacesInterfaceInterfaceNameOperStatusPatch has not yet been implemented")
		})
	}
	if api.DataDataCocsnInterfacesInterfaceInterfaceNameOperStatusPutHandler == nil {
		api.DataDataCocsnInterfacesInterfaceInterfaceNameOperStatusPutHandler = data.DataCocsnInterfacesInterfaceInterfaceNameOperStatusPutHandlerFunc(func(params data.DataCocsnInterfacesInterfaceInterfaceNameOperStatusPutParams, principal interface{}) middleware.Responder {
			return middleware.NotImplemented("operation data.DataCocsnInterfacesInterfaceInterfaceNameOperStatusPut has not yet been implemented")
		})
	}
	if api.DataDataCocsnInterfacesInterfaceInterfaceNamePatchHandler == nil {
		api.DataDataCocsnInterfacesInterfaceInterfaceNamePatchHandler = data.DataCocsnInterfacesInterfaceInterfaceNamePatchHandlerFunc(func(params data.DataCocsnInterfacesInterfaceInterfaceNamePatchParams, principal interface{}) middleware.Responder {
			return middleware.NotImplemented("operation data.DataCocsnInterfacesInterfaceInterfaceNamePatch has not yet been implemented")
		})
	}
	if api.DataDataCocsnInterfacesInterfaceInterfaceNamePhysAddressGetHandler == nil {
		api.DataDataCocsnInterfacesInterfaceInterfaceNamePhysAddressGetHandler = data.DataCocsnInterfacesInterfaceInterfaceNamePhysAddressGetHandlerFunc(func(params data.DataCocsnInterfacesInterfaceInterfaceNamePhysAddressGetParams, principal interface{}) middleware.Responder {
			return middleware.NotImplemented("operation data.DataCocsnInterfacesInterfaceInterfaceNamePhysAddressGet has not yet been implemented")
		})
	}
	if api.DataDataCocsnInterfacesInterfaceInterfaceNamePutHandler == nil {
		api.DataDataCocsnInterfacesInterfaceInterfaceNamePutHandler = data.DataCocsnInterfacesInterfaceInterfaceNamePutHandlerFunc(func(params data.DataCocsnInterfacesInterfaceInterfaceNamePutParams, principal interface{}) middleware.Responder {
			return middleware.NotImplemented("operation data.DataCocsnInterfacesInterfaceInterfaceNamePut has not yet been implemented")
		})
	}
	if api.DataDataCocsnInterfacesPatchHandler == nil {
		api.DataDataCocsnInterfacesPatchHandler = data.DataCocsnInterfacesPatchHandlerFunc(func(params data.DataCocsnInterfacesPatchParams, principal interface{}) middleware.Responder {
			return middleware.NotImplemented("operation data.DataCocsnInterfacesPatch has not yet been implemented")
		})
	}
	if api.DataDataCocsnInterfacesPostHandler == nil {
		api.DataDataCocsnInterfacesPostHandler = data.DataCocsnInterfacesPostHandlerFunc(func(params data.DataCocsnInterfacesPostParams, principal interface{}) middleware.Responder {
			return middleware.NotImplemented("operation data.DataCocsnInterfacesPost has not yet been implemented")
		})
	}
	if api.DataDataCocsnInterfacesPutHandler == nil {
		api.DataDataCocsnInterfacesPutHandler = data.DataCocsnInterfacesPutHandlerFunc(func(params data.DataCocsnInterfacesPutParams, principal interface{}) middleware.Responder {
			return middleware.NotImplemented("operation data.DataCocsnInterfacesPut has not yet been implemented")
		})
	}
	if api.DataDataCocsnRoutesDeleteHandler == nil {
		api.DataDataCocsnRoutesDeleteHandler = data.DataCocsnRoutesDeleteHandlerFunc(func(params data.DataCocsnRoutesDeleteParams, principal interface{}) middleware.Responder {
			return middleware.NotImplemented("operation data.DataCocsnRoutesDelete has not yet been implemented")
		})
	}
	if api.DataDataCocsnRoutesGetHandler == nil {
		api.DataDataCocsnRoutesGetHandler = data.DataCocsnRoutesGetHandlerFunc(func(params data.DataCocsnRoutesGetParams, principal interface{}) middleware.Responder {
			return middleware.NotImplemented("operation data.DataCocsnRoutesGet has not yet been implemented")
		})
	}
	if api.DataDataCocsnRoutesPatchHandler == nil {
		api.DataDataCocsnRoutesPatchHandler = data.DataCocsnRoutesPatchHandlerFunc(func(params data.DataCocsnRoutesPatchParams, principal interface{}) middleware.Responder {
			return middleware.NotImplemented("operation data.DataCocsnRoutesPatch has not yet been implemented")
		})
	}
	if api.DataDataCocsnRoutesPostHandler == nil {
		api.DataDataCocsnRoutesPostHandler = data.DataCocsnRoutesPostHandlerFunc(func(params data.DataCocsnRoutesPostParams, principal interface{}) middleware.Responder {
			return middleware.NotImplemented("operation data.DataCocsnRoutesPost has not yet been implemented")
		})
	}
	if api.DataDataCocsnRoutesPutHandler == nil {
		api.DataDataCocsnRoutesPutHandler = data.DataCocsnRoutesPutHandlerFunc(func(params data.DataCocsnRoutesPutParams, principal interface{}) middleware.Responder {
			return middleware.NotImplemented("operation data.DataCocsnRoutesPut has not yet been implemented")
		})
	}
	if api.DataDataCocsnRoutesRouteRouteDestinationDeleteHandler == nil {
		api.DataDataCocsnRoutesRouteRouteDestinationDeleteHandler = data.DataCocsnRoutesRouteRouteDestinationDeleteHandlerFunc(func(params data.DataCocsnRoutesRouteRouteDestinationDeleteParams, principal interface{}) middleware.Responder {
			return middleware.NotImplemented("operation data.DataCocsnRoutesRouteRouteDestinationDelete has not yet been implemented")
		})
	}
	if api.DataDataCocsnRoutesRouteRouteDestinationDestinationDeleteHandler == nil {
		api.DataDataCocsnRoutesRouteRouteDestinationDestinationDeleteHandler = data.DataCocsnRoutesRouteRouteDestinationDestinationDeleteHandlerFunc(func(params data.DataCocsnRoutesRouteRouteDestinationDestinationDeleteParams, principal interface{}) middleware.Responder {
			return middleware.NotImplemented("operation data.DataCocsnRoutesRouteRouteDestinationDestinationDelete has not yet been implemented")
		})
	}
	if api.DataDataCocsnRoutesRouteRouteDestinationDestinationGetHandler == nil {
		api.DataDataCocsnRoutesRouteRouteDestinationDestinationGetHandler = data.DataCocsnRoutesRouteRouteDestinationDestinationGetHandlerFunc(func(params data.DataCocsnRoutesRouteRouteDestinationDestinationGetParams, principal interface{}) middleware.Responder {
			return middleware.NotImplemented("operation data.DataCocsnRoutesRouteRouteDestinationDestinationGet has not yet been implemented")
		})
	}
	if api.DataDataCocsnRoutesRouteRouteDestinationDestinationPatchHandler == nil {
		api.DataDataCocsnRoutesRouteRouteDestinationDestinationPatchHandler = data.DataCocsnRoutesRouteRouteDestinationDestinationPatchHandlerFunc(func(params data.DataCocsnRoutesRouteRouteDestinationDestinationPatchParams, principal interface{}) middleware.Responder {
			return middleware.NotImplemented("operation data.DataCocsnRoutesRouteRouteDestinationDestinationPatch has not yet been implemented")
		})
	}
	if api.DataDataCocsnRoutesRouteRouteDestinationDestinationPutHandler == nil {
		api.DataDataCocsnRoutesRouteRouteDestinationDestinationPutHandler = data.DataCocsnRoutesRouteRouteDestinationDestinationPutHandlerFunc(func(params data.DataCocsnRoutesRouteRouteDestinationDestinationPutParams, principal interface{}) middleware.Responder {
			return middleware.NotImplemented("operation data.DataCocsnRoutesRouteRouteDestinationDestinationPut has not yet been implemented")
		})
	}
	if api.DataDataCocsnRoutesRouteRouteDestinationExpireDeleteHandler == nil {
		api.DataDataCocsnRoutesRouteRouteDestinationExpireDeleteHandler = data.DataCocsnRoutesRouteRouteDestinationExpireDeleteHandlerFunc(func(params data.DataCocsnRoutesRouteRouteDestinationExpireDeleteParams, principal interface{}) middleware.Responder {
			return middleware.NotImplemented("operation data.DataCocsnRoutesRouteRouteDestinationExpireDelete has not yet been implemented")
		})
	}
	if api.DataDataCocsnRoutesRouteRouteDestinationExpireGetHandler == nil {
		api.DataDataCocsnRoutesRouteRouteDestinationExpireGetHandler = data.DataCocsnRoutesRouteRouteDestinationExpireGetHandlerFunc(func(params data.DataCocsnRoutesRouteRouteDestinationExpireGetParams, principal interface{}) middleware.Responder {
			return middleware.NotImplemented("operation data.DataCocsnRoutesRouteRouteDestinationExpireGet has not yet been implemented")
		})
	}
	if api.DataDataCocsnRoutesRouteRouteDestinationExpirePatchHandler == nil {
		api.DataDataCocsnRoutesRouteRouteDestinationExpirePatchHandler = data.DataCocsnRoutesRouteRouteDestinationExpirePatchHandlerFunc(func(params data.DataCocsnRoutesRouteRouteDestinationExpirePatchParams, principal interface{}) middleware.Responder {
			return middleware.NotImplemented("operation data.DataCocsnRoutesRouteRouteDestinationExpirePatch has not yet been implemented")
		})
	}
	if api.DataDataCocsnRoutesRouteRouteDestinationExpirePutHandler == nil {
		api.DataDataCocsnRoutesRouteRouteDestinationExpirePutHandler = data.DataCocsnRoutesRouteRouteDestinationExpirePutHandlerFunc(func(params data.DataCocsnRoutesRouteRouteDestinationExpirePutParams, principal interface{}) middleware.Responder {
			return middleware.NotImplemented("operation data.DataCocsnRoutesRouteRouteDestinationExpirePut has not yet been implemented")
		})
	}
	if api.DataDataCocsnRoutesRouteRouteDestinationFlagsDeleteHandler == nil {
		api.DataDataCocsnRoutesRouteRouteDestinationFlagsDeleteHandler = data.DataCocsnRoutesRouteRouteDestinationFlagsDeleteHandlerFunc(func(params data.DataCocsnRoutesRouteRouteDestinationFlagsDeleteParams, principal interface{}) middleware.Responder {
			return middleware.NotImplemented("operation data.DataCocsnRoutesRouteRouteDestinationFlagsDelete has not yet been implemented")
		})
	}
	if api.DataDataCocsnRoutesRouteRouteDestinationFlagsGetHandler == nil {
		api.DataDataCocsnRoutesRouteRouteDestinationFlagsGetHandler = data.DataCocsnRoutesRouteRouteDestinationFlagsGetHandlerFunc(func(params data.DataCocsnRoutesRouteRouteDestinationFlagsGetParams, principal interface{}) middleware.Responder {
			return middleware.NotImplemented("operation data.DataCocsnRoutesRouteRouteDestinationFlagsGet has not yet been implemented")
		})
	}
	if api.DataDataCocsnRoutesRouteRouteDestinationFlagsPatchHandler == nil {
		api.DataDataCocsnRoutesRouteRouteDestinationFlagsPatchHandler = data.DataCocsnRoutesRouteRouteDestinationFlagsPatchHandlerFunc(func(params data.DataCocsnRoutesRouteRouteDestinationFlagsPatchParams, principal interface{}) middleware.Responder {
			return middleware.NotImplemented("operation data.DataCocsnRoutesRouteRouteDestinationFlagsPatch has not yet been implemented")
		})
	}
	if api.DataDataCocsnRoutesRouteRouteDestinationFlagsPutHandler == nil {
		api.DataDataCocsnRoutesRouteRouteDestinationFlagsPutHandler = data.DataCocsnRoutesRouteRouteDestinationFlagsPutHandlerFunc(func(params data.DataCocsnRoutesRouteRouteDestinationFlagsPutParams, principal interface{}) middleware.Responder {
			return middleware.NotImplemented("operation data.DataCocsnRoutesRouteRouteDestinationFlagsPut has not yet been implemented")
		})
	}
	if api.DataDataCocsnRoutesRouteRouteDestinationGatewayDeleteHandler == nil {
		api.DataDataCocsnRoutesRouteRouteDestinationGatewayDeleteHandler = data.DataCocsnRoutesRouteRouteDestinationGatewayDeleteHandlerFunc(func(params data.DataCocsnRoutesRouteRouteDestinationGatewayDeleteParams, principal interface{}) middleware.Responder {
			return middleware.NotImplemented("operation data.DataCocsnRoutesRouteRouteDestinationGatewayDelete has not yet been implemented")
		})
	}
	if api.DataDataCocsnRoutesRouteRouteDestinationGatewayGetHandler == nil {
		api.DataDataCocsnRoutesRouteRouteDestinationGatewayGetHandler = data.DataCocsnRoutesRouteRouteDestinationGatewayGetHandlerFunc(func(params data.DataCocsnRoutesRouteRouteDestinationGatewayGetParams, principal interface{}) middleware.Responder {
			return middleware.NotImplemented("operation data.DataCocsnRoutesRouteRouteDestinationGatewayGet has not yet been implemented")
		})
	}
	if api.DataDataCocsnRoutesRouteRouteDestinationGatewayPatchHandler == nil {
		api.DataDataCocsnRoutesRouteRouteDestinationGatewayPatchHandler = data.DataCocsnRoutesRouteRouteDestinationGatewayPatchHandlerFunc(func(params data.DataCocsnRoutesRouteRouteDestinationGatewayPatchParams, principal interface{}) middleware.Responder {
			return middleware.NotImplemented("operation data.DataCocsnRoutesRouteRouteDestinationGatewayPatch has not yet been implemented")
		})
	}
	if api.DataDataCocsnRoutesRouteRouteDestinationGatewayPutHandler == nil {
		api.DataDataCocsnRoutesRouteRouteDestinationGatewayPutHandler = data.DataCocsnRoutesRouteRouteDestinationGatewayPutHandlerFunc(func(params data.DataCocsnRoutesRouteRouteDestinationGatewayPutParams, principal interface{}) middleware.Responder {
			return middleware.NotImplemented("operation data.DataCocsnRoutesRouteRouteDestinationGatewayPut has not yet been implemented")
		})
	}
	if api.DataDataCocsnRoutesRouteRouteDestinationGetHandler == nil {
		api.DataDataCocsnRoutesRouteRouteDestinationGetHandler = data.DataCocsnRoutesRouteRouteDestinationGetHandlerFunc(func(params data.DataCocsnRoutesRouteRouteDestinationGetParams, principal interface{}) middleware.Responder {
			return middleware.NotImplemented("operation data.DataCocsnRoutesRouteRouteDestinationGet has not yet been implemented")
		})
	}
	if api.DataDataCocsnRoutesRouteRouteDestinationInterfaceDeleteHandler == nil {
		api.DataDataCocsnRoutesRouteRouteDestinationInterfaceDeleteHandler = data.DataCocsnRoutesRouteRouteDestinationInterfaceDeleteHandlerFunc(func(params data.DataCocsnRoutesRouteRouteDestinationInterfaceDeleteParams, principal interface{}) middleware.Responder {
			return middleware.NotImplemented("operation data.DataCocsnRoutesRouteRouteDestinationInterfaceDelete has not yet been implemented")
		})
	}
	if api.DataDataCocsnRoutesRouteRouteDestinationInterfaceGetHandler == nil {
		api.DataDataCocsnRoutesRouteRouteDestinationInterfaceGetHandler = data.DataCocsnRoutesRouteRouteDestinationInterfaceGetHandlerFunc(func(params data.DataCocsnRoutesRouteRouteDestinationInterfaceGetParams, principal interface{}) middleware.Responder {
			return middleware.NotImplemented("operation data.DataCocsnRoutesRouteRouteDestinationInterfaceGet has not yet been implemented")
		})
	}
	if api.DataDataCocsnRoutesRouteRouteDestinationInterfacePatchHandler == nil {
		api.DataDataCocsnRoutesRouteRouteDestinationInterfacePatchHandler = data.DataCocsnRoutesRouteRouteDestinationInterfacePatchHandlerFunc(func(params data.DataCocsnRoutesRouteRouteDestinationInterfacePatchParams, principal interface{}) middleware.Responder {
			return middleware.NotImplemented("operation data.DataCocsnRoutesRouteRouteDestinationInterfacePatch has not yet been implemented")
		})
	}
	if api.DataDataCocsnRoutesRouteRouteDestinationInterfacePutHandler == nil {
		api.DataDataCocsnRoutesRouteRouteDestinationInterfacePutHandler = data.DataCocsnRoutesRouteRouteDestinationInterfacePutHandlerFunc(func(params data.DataCocsnRoutesRouteRouteDestinationInterfacePutParams, principal interface{}) middleware.Responder {
			return middleware.NotImplemented("operation data.DataCocsnRoutesRouteRouteDestinationInterfacePut has not yet been implemented")
		})
	}
	if api.DataDataCocsnRoutesRouteRouteDestinationPatchHandler == nil {
		api.DataDataCocsnRoutesRouteRouteDestinationPatchHandler = data.DataCocsnRoutesRouteRouteDestinationPatchHandlerFunc(func(params data.DataCocsnRoutesRouteRouteDestinationPatchParams, principal interface{}) middleware.Responder {
			return middleware.NotImplemented("operation data.DataCocsnRoutesRouteRouteDestinationPatch has not yet been implemented")
		})
	}
	if api.DataDataCocsnRoutesRouteRouteDestinationPutHandler == nil {
		api.DataDataCocsnRoutesRouteRouteDestinationPutHandler = data.DataCocsnRoutesRouteRouteDestinationPutHandlerFunc(func(params data.DataCocsnRoutesRouteRouteDestinationPutParams, principal interface{}) middleware.Responder {
			return middleware.NotImplemented("operation data.DataCocsnRoutesRouteRouteDestinationPut has not yet been implemented")
		})
	}
	if api.DataDataGetHandler == nil {
		api.DataDataGetHandler = data.DataGetHandlerFunc(func(params data.DataGetParams, principal interface{}) middleware.Responder {
			return middleware.NotImplemented("operation data.DataGet has not yet been implemented")
		})
	}
	if api.DataDataPatchHandler == nil {
		api.DataDataPatchHandler = data.DataPatchHandlerFunc(func(params data.DataPatchParams, principal interface{}) middleware.Responder {
			return middleware.NotImplemented("operation data.DataPatch has not yet been implemented")
		})
	}
	if api.DataDataPostHandler == nil {
		api.DataDataPostHandler = data.DataPostHandlerFunc(func(params data.DataPostParams, principal interface{}) middleware.Responder {
			return middleware.NotImplemented("operation data.DataPost has not yet been implemented")
		})
	}
	if api.DataDataPutHandler == nil {
		api.DataDataPutHandler = data.DataPutHandlerFunc(func(params data.DataPutParams, principal interface{}) middleware.Responder {
			return middleware.NotImplemented("operation data.DataPut has not yet been implemented")
		})
	}
	if api.OperationsopsOperationsGetHandler == nil {
		api.OperationsopsOperationsGetHandler = operationsops.OperationsGetHandlerFunc(func(params operationsops.OperationsGetParams, principal interface{}) middleware.Responder {
			return middleware.NotImplemented("operation operationsops.OperationsGet has not yet been implemented")
		})
	}
	if api.RootRootGetHandler == nil {
		api.RootRootGetHandler = root.RootGetHandlerFunc(func(params root.RootGetParams, principal interface{}) middleware.Responder {
			return middleware.NotImplemented("operation root.RootGet has not yet been implemented")
		})
	}
	if api.YangLibraryVersionYangLibraryVersionGetHandler == nil {
		api.YangLibraryVersionYangLibraryVersionGetHandler = yang_library_version.YangLibraryVersionGetHandlerFunc(func(params yang_library_version.YangLibraryVersionGetParams, principal interface{}) middleware.Responder {
			return middleware.NotImplemented("operation yang_library_version.YangLibraryVersionGet has not yet been implemented")
		})
	}

	api.PreServerShutdown = func() {}

	api.ServerShutdown = func() {}

	return setupGlobalMiddleware(api.Serve(setupMiddlewares))
}

// The TLS configuration before HTTPS server starts.
func configureTLS(tlsConfig *tls.Config) {
	// Make all necessary changes to the TLS configuration here.
}

// As soon as server is initialized but not run yet, this function will be called.
// If you need to modify a config, store server instance to stop it individually later, this is the place.
// This function can be called multiple times, depending on the number of serving schemes.
// scheme value will be set accordingly: "http", "https" or "unix"
func configureServer(s *http.Server, scheme, addr string) {
}

// The middleware configuration is for the handler executors. These do not apply to the swagger.json document.
// The middleware executes after routing but before authentication, binding and validation
func setupMiddlewares(handler http.Handler) http.Handler {
	return handler
}

// The middleware configuration happens before anything, this middleware also applies to serving the swagger.json document.
// So this is a good place to plug in a panic handling middleware, logging and metrics
func setupGlobalMiddleware(handler http.Handler) http.Handler {
	return handler
}
